# yiwen song

[Personal Site](http://yiwensong.com) |
[Email](mailto:songzgy@gmail.com)

---
## Education
### University of California, Berkeley - June 2016

Computer Science, B.A.  
Major GPA: 3.739  

---
## Work Experience
### Release Engineering at Yelp (Nov 2017 - Present)
*San Francisco, CA*

* Worked on Jenkins continuous deployment and integration of Yelp services.
* Designed and implemented API for determining responsibility and ownership of code, databases, and other resources.
* Improved Git management tools and code review infrastructure to be more resilient to catastrophic failures.

### Trading and Data at Old Mission Capital (Aug 2016 - May 2017)
*Chicago, IL*

* Improved data pipeline and research infrastructure reliability and usability.
* Added parallelism to data ingestion and created automated sanity checking to reduce overhead of analysis.
* Developed a Python package for quickly scripting models and risk calculation on live market data.

### Trading Intern at Old Mission Capital (Jun 2015 - Aug 2015)
*Chicago, IL*

* Studied the effect of US high frequency trading on international markets.
* Used Python (Scikit-Learn, Matplotlib) to analyze data and visualize stastical models.
* Wrote research reports to communicate studies to traders whose products were impacted by the studies.

---
## Projects
### [GPU Compression](https://github.com/yiwensong/lzss)

* Parallelized implementation of LZSS compression for the GPU.
* The goal of the project was to test feasibility of using message compression in HPC applications.
* Result: your network needs to be *really* bad for this to be worth anything.
* Implemented in CUDA and deployed on AWS.

### [ImgCompress](https://github.com/yiwensong/imgcompress)

* ImgCompress is a hackathon project aimed at becoming the future of compression.
* Uploads binaries to Imgur as PNGs and stores the 7 character Imgur URL.
* Compression ratio is over 700 000 and implementation is less than 200 lines of python.
* Better than the CUDA stuff I made.

### [Poker AI](https://github.com/yiwensong/huplo)

* Heads Up Pot-Limit Omaha (HUPLO) AI that uses Monte Carlo search trees and bad machine learning.
* Preflop play uses machine learning on hole cards features like connectedness, suitedness and value.
* Postflop play uses Monte Carlo Search Trees.
* 💩 at poker.
* Passable at Tic-Tac-Toe.

### [Yet Another Personal Site | DefDontHire.Me](https://github.com/yiwensong/yiwensong.github.io)

* Technology has advanced to a point where you can create a beautiful website without knowing any web.
* Literally anyone can download a Bootstrap template and write some BS and call it a personal site.
* [Exhibit A](http://yiwensong.com)

### [yiwen.date](https://github.com/yiwensong/yiwen.date)

* Another personal site, but maybe a little more personal.
* Frontend written in react, backend written with Flask.
* [Please do not attempt to date potential future employees.](https://yiwen.date)

---
## Interests, Skills and Intangibles
**Hobbies**: Board Games, Poker, Basketball, Reading the Manual  
**Language**: Python, Javascript, Psuedocode, fish, Mandarin  
**Skills**: INDEX-MATCH Fiend, Vim Connoiseur, Nash Equilibrium Hobbyist, "sudo rm -rf /" Frequent User  
**Intangibles**: Enjoys friendly competition, clicks buttons really fast  
